Demonstration files — pbxplore.demo — PBxplore 1.1 documentation

# Demonstration files — `pbxplore.demo`

PBxplore bundles a set of demonstration files. This module ease the access to these files.

The path to the demonstration files is stored in `DEMO_DATA_PATH`. This constant can be accessed as `pbxplore.demo.DEMO_DATA_PATH`, or as `pbxplore.DEMO_DATA_PATH`.

A list of the available demonstration files is available with the `list_demo_files()` function. The same list with absolute path instead of file names is provided by `list_demo_files_absolute()`.

`pbxplore.demo.` `list_demo_files`()

  List the names of the bundled demo files

  File names starting with _ or . are not listed. This allows to omit __init__.py, and hiden files.

`pbxplore.demo.` `list_demo_files_absolute`()

  List the absolute path to the bundled demo files

  File names starting with _ or . are not listed. This allows to omit __init__.py, and hiden files.